@@ -48,13 +48,8 @@ def add_alarm_status(
         print(new_alarm_status)
     """
     alarm_status_input = AddAlarmStatusInput(name=name)
-    if alarm_status_input.name =="": 
-        print ("you cant leave the name parameter empty")
-    elif alarm_status_input.name != str:
-        print ("the input must be a text, example name=\"new name\"")
-    else:
-        result = addAlarmStatus.execute(client, input=alarm_status_input)
-        return alarmStatus(name=result.name, id=result.id)
+    result = addAlarmStatus.execute(client, input=alarm_status_input)
+    return alarmStatus(name=result.name, id=result.id)
 
 
 def edit_alarm_status(
